@@ -85,15 +85,6 @@ test_that("Different distances method give consistent results", {
 
   gow_mat = compute_dist_matrix(trait_df, metric = "gower")
 
-  if (requireNamespace("StatMatch", quietly = TRUE)) {
-
-    gow_dist = StatMatch::gower.dist(trait_df)
-    rownames(gow_dist) = rownames(trait_df)
-    colnames(gow_dist) = rownames(trait_df)
-
-    expect_equal(gow_mat, gow_dist)
-  }
-
   other_gow_dist = as.matrix(cluster::daisy(trait_df, "gower"))
 
   expect_equal(def_mat, gow_mat)
